@@ -1,6 +1,6 @@
 #!/bin/bash
 
-#Copyright (C) since 2006 NTT DATA Corporation
+#Copyright (C) 2006 - 2009 NTT DATA Corporation
 #
 #This program is free software; you can redistribute it and/or
 #Modify it under the terms of the GNU General Public License
@@ -15,9 +15,10 @@
 
 # check for incorrect use
 EXEC_USER=`/usr/bin/whoami`
-if [ ${EXEC_USER} != "hinemos" -a ${EXEC_USER} != "root" ]; then
+if [ "x"${EXEC_USER} != "x"${HINEMOS_JBOSS_USER} ]; then
         echo "";
-        echo "ERROR  Hinemos Maneger boot at incorrect user ";
+        echo "ERROR  Hinemos JBoss boot at incorrect user ";
+        echo "Please check /opt/hinemos/hinemos.cfg (HINEMOS_JBOSS_USER)"
         echo "";
         exit 1;
 fi
@@ -30,8 +31,6 @@ if [ $# = 0 ] ;then
     fi
 fi
 
-STARTUP_WAIT=true
-
 for OPTION in "$@"
 do
 	case $OPTION in
@@ -44,14 +43,10 @@ do
 		-c)
 			. ${HINEMOS_HOME}/sbin/mng/hinemos_clear_jbm.sh
 			;;
-		-W)
-			STARTUP_WAIT=false
-			;;
 		*)
 			echo "usage"
 			echo "jboss_start.sh    : JBoss is started as usual. "
 			echo "jboss_start.sh -c : After the JMS message is annulled, JBoss is started. "
-			echo "jboss_start.sh -W : startup JBoss (not wait for the start to complete)"
 			exit 1
 			;;
 	esac
@@ -104,11 +99,6 @@ cd ${HINEMOS_HOME}/var/log
 
 while [ 1 ];
 do
-	if [ "x${STARTUP_WAIT}" == "xfalse" ]
-	then
-		break
-	fi
-
         if [ -f ${HINEMOS_HOME}/var/log/jboss.log ]; then
                 LOG_DATE=`tail -1 /opt/hinemos/var/log/jboss.log | gawk -F\  '{ print $1 }'`
                 if [ "${TODAY}" = "${LOG_DATE}" ];  then
