@@ -1,6 +1,6 @@
 #!/bin/bash
 
-#Copyright (C) since 2006 NTT DATA Corporation
+#Copyright (C) 2006 - 2009 NTT DATA Corporation
 #
 #This program is free software; you can redistribute it and/or
 #Modify it under the terms of the GNU General Public License
@@ -53,4 +53,4 @@ if [ -f ${HINEMOS_JBOSS_PID} ]; then
     fi
 fi
                                                                                                      
-echo "jboss stoped"
+echo "jboss stopped"
