@@ -1,6 +1,6 @@
 #!/bin/sh
 
-#Copyright (C) since 2006 NTT DATA Corporation
+#Copyright (C) 2006 - 2009 NTT DATA Corporation
 #
 #This program is free software; you can redistribute it and/or
 #Modify it under the terms of the GNU General Public License
@@ -29,4 +29,4 @@ if [ -f ${HINEMOS_PG_PID} ] ; then
         fi
 fi
 
-${PG}/bin/pg_ctl start -w -D ${PGDATA}
+${PG}/bin/pg_ctl start -w -D ${PGDATA} > /dev/null 2>&1
