@@ -27,7 +27,7 @@ SSH_KEYGEN="/usr/bin/ssh-keygen -t rsa"
 MKDIR=/bin/mkdir
 CHMOD=/bin/chmod
 
-VERSION=`cat ${EXEC_PATH}/hinemos/_version`
+VERSION=`cat ${HINEMOS_HOME}/_version`
 
 echo ""
 echo "###################################################################"
@@ -149,10 +149,10 @@ entry() {
 		AGENT_AUTHORIZED_KEYS=${ROOT_HOME}.ssh/authorized_keys
 		case ${ANS} in
 		    y|Y)
-			ssh root@${AGENT_IP} command "
-                            if [ ! -d ${ROOT_HOME}/.ssh ] ; then
-                                ${MKDIR} ${ROOT_HOME}/.ssh
-                                ${CHMOD} 700 ${ROOT_HOME}/.ssh
+			ssh root@${AGENT_IP} "
+                            if [ ! -d ${ROOT_HOME}.ssh ] ; then
+                                ${MKDIR} ${ROOT_HOME}.ssh
+                                ${CHMOD} 700 ${ROOT_HOME}.ssh
                             fi
                             echo ${MANAGER_KEY} >> ${AGENT_AUTHORIZED_KEYS}
                             ${CHMOD} 600 ${AGENT_AUTHORIZED_KEYS}
