@@ -14,16 +14,11 @@ begin;
 
 SELECT session_id  INTO TEMPORARY cc_job_completed_sessions
     FROM cc_job_session_job 
-        WHERE  status='300' AND (job_id, session_id ) IN (select job_id,session_id FROM cc_job_session);
+        WHERE (status='300' OR status='301') AND (job_id, session_id ) IN (select job_id,session_id FROM cc_job_session);
 
 --# execute 
 
-DELETE FROM cc_job_session WHERE session_id IN (select session_id from cc_job_session_job where (status='300' OR status='301'));
-
---# DELETE FROM cc_job_param_info
---#    WHERE ( session_id ) IN (
---#        select session_id from cc_job_completed_sessions
---#    );
+DELETE FROM cc_job_session WHERE session_id IN (select session_id from cc_job_completed_sessions);
 
 DELETE FROM cc_notify_relation_info
     WHERE ( notify_group_id ) like any (
